@@ -535,8 +535,10 @@ class TestPromoteBatch(DLRNAPITestCase):
         os.makedirs('/tmp/component/tripleo')
 
     def tearDown(self):
-        shutil.rmtree('/tmp/component/None')
-        shutil.rmtree('/tmp/component/tripleo')
+        if os.path.exists('/tmp/component/None'):
+            shutil.rmtree('/tmp/component/None')
+        if os.path.exists('/tmp/component/tripleo'):
+            shutil.rmtree('/tmp/component/tripleo')
         super(TestPromoteBatch, self).tearDown()
 
     def test_promote_batch_needs_auth(self, db2_mock, db_mock):
@@ -817,15 +819,45 @@ class TestGetCIAggVotes(DLRNAPITestCase):
 @mock.patch('dlrn.api.dlrn_api.getSession', side_effect=mocked_session)
 @mock.patch('dlrn.api.utils.getSession', side_effect=mocked_session)
 class TestGetReport(DLRNAPITestCase):
-    def test_get_report(self, db2_mock, db_mock, rt_mock):
+
+    @mock.patch('dlrn.db.Commit.getshardedcommitdir')
+    def test_get_report(self, commit_mock, db2_mock, db_mock, rt_mock):
         response = self.app.get('/api/report.html')
         self.assertEqual(rt_mock.call_count, 1)
         self.assertEqual(response.status_code, 200)
+        assert commit_mock.called
 
-    def test_get_report_detail(self, db2_mock, db_mock, rt_mock):
+    @mock.patch('dlrn.db.Commit.getshardedcommitdir')
+    def test_get_report_detail(self, commit_mock, db2_mock, db_mock, rt_mock):
+        response = self.app.get('/api/report.html?package=python-pysaml2'
+                                '&success=1')
+        self.assertEqual(1, rt_mock.call_args.kwargs['count'])
+        self.assertEqual(response.status_code, 200)
+        assert commit_mock.called
+
+    def test_get_report_detail_wrong_query(self, db2_mock, db_mock, rt_mock):
         response = self.app.get('/api/report.html?project=python-pysaml2'
                                 '&success=1')
-        self.assertEqual(rt_mock.call_count, 1)
+        self.assertTrue(rt_mock.call_args.kwargs['count'] != 1)
+        self.assertEqual(response.status_code, 200)
+
+    def test_get_package_version(self, db2_mock, db_mock, rt_mock):
+        response = self.app.get('/api/report.html')
+        package_info = rt_mock.call_args.kwargs['commits_build_dir'].get(
+            '93eee77657978547f5fad1cb8cd30b570da83e68')
+        self.assertEqual('6.1.1', package_info.get('version'))
+        self.assertEqual('0.20200421095106.5aa891c.el7',
+                         package_info.get('release'))
+        self.assertEqual(response.status_code, 200)
+
+    def test_get_package_version_wrong_version(self, db2_mock, db_mock,
+                                               rt_mock):
+        response = self.app.get('/api/report.html')
+        package_info = rt_mock.call_args.kwargs['commits_build_dir'].get(
+            '1c67b1ab8c6fe273d4e175a14f0df5d3cbbd0e77')
+        self.assertEqual('0.8.3-0.99.20150907.2338git.el7.centos.src.rpm',
+                         package_info.get('version'))
+        self.assertEqual('', package_info.get('release'))
         self.assertEqual(response.status_code, 200)
 
 
@@ -972,8 +1004,8 @@ class TestMetrics(DLRNAPITestCase):
                                 content_type='application/json')
         self.assertEqual(response.status_code, 200)
         data = json.loads(response.data)
-        self.assertEqual(data['total'], 3)
-        self.assertEqual(data['succeeded'], 3)
+        self.assertEqual(data['total'], 4)
+        self.assertEqual(data['succeeded'], 4)
         self.assertEqual(data['failed'], 0)
 
     def test_metrics_success_url_param(self, db2_mock, db_mock):
@@ -981,8 +1013,8 @@ class TestMetrics(DLRNAPITestCase):
                                 '&end_date=2015-09-09')
         self.assertEqual(response.status_code, 200)
         data = json.loads(response.data)
-        self.assertEqual(data['total'], 3)
-        self.assertEqual(data['succeeded'], 3)
+        self.assertEqual(data['total'], 4)
+        self.assertEqual(data['succeeded'], 4)
         self.assertEqual(data['failed'], 0)
 
     def test_metrics_filtered(self, db2_mock, db_mock):
